1. Piotr Maślanka - director
2. Martyna Wyrzykowska - deputy director
3. Patryk Świętoń - data analyst
4. Kacper Stysło - Python developer
5. Marcin Zdunek - Python developer
6. Diana Sditanova - language expert
7. Angelika Hejnar - language export
